# Stython - A Starshooter project
A python package used to simplify complicated syntax of python, and add some of its own syntax.
## What does stython include?
Stython incorporates simplified versions of both regular python and popular modules such as random and time.  

It also includes its own syntax such as some Hexadecimal number functions, the well known missing python function, the Switch statement.